@@ -89,7 +89,7 @@ class Lang:
             trans = lambda x: x
         else:
             la = [l]
-            reload(gettext)
+            # reload(gettext)
             if gettext.find(self.nameDomain, self.__catalog, la):
                 """Если найден словарь то инициализируем переводчик"""
                 transl = gettext.translation(self.nameDomain, self.__catalog,
